@@ -323,10 +323,10 @@ class VotingModel():
         fprefix=None,
         title_core='Core (aborbing) points',
         title_sad='L1 norm of difference in two rows of P^power',
-        title_diff1='L1 norm of change in row1 (grid corner)',
-        title_diff2='L1 norm of change in middle row (grid center)',
-        title_sum1minus1='Sum of row1 (grid corner), minus 1.0',
-        title_sum2minus1='Sum of middle row (grid center), minus 1.0',
+        title_diff1='L1 norm of change in corner row',
+        title_diff2='L1 norm of change in center row',
+        title_sum1minus1='Corner row sum minus 1.0',
+        title_sum2minus1='Center row sum minus 1.0',
         title_unreachable_points='Dominated (unreachable) points',
         title_stationary_distribution_no_grid='Stationary Distribution',
         title_stationary_distribution='Stationary Distribution',
